# Commands

The OU Container Builder provides the following command-line commands:

* `ocb version`
* `ocb generate`
* `ocb build`
* `ocb clean`

## Version

Outputs the version of the OU Container Builder:

:::{code-block} shell
$ ocb version
3.0.0
:::

## Generate

Generates the the `Dockerfile` and all auxiliary files needed for building a VCE image, but does not actually run the
build process. The `generate` command is used to run this process and **must** be run in the directory containing the
`ContainerConfig.yaml`.

:::{code-block} shell-session
$ ocb generate
:::

## Build

Generates the the `Dockerfile` and all auxiliary files needed for building a VCE image, and then runs the build process.
For this to work [Buildah](https://buildah.io/) needs to be installed. The `build` command is used to run this process
and **must** be run in the directory containing the `ContainerConfig.yaml`.

The `build` command supports the `--tag TAG` parameter, which can be specified multiple times. The tags are passed through
to Buildah and are used to tag the resulting images.

:::{code-block} shell-session
$ ocb build --tag module:latest
:::

## Clean

Cleans any generated `Dockerfile` and all auxiliary files generated by the `generate` command. The `clean` command is used
to run this process and **must** be run in the directory containing the `ContainerConfig.yaml`.

:::{code-block} shell-session
$ ocb clean
:::
